TranslationsCompanion class

Constructors

TranslationsCompanion({Value<String> originalTextHash = const Value.absent(), Value<String> translatedText = const Value.absent(), Value<SolvroLocale> originalLanguageCode = const Value.absent(), Value<SolvroLocale> translatedLanguageCode = const Value.absent(), Value<bool> isApproved = const Value.absent(), Value<DateTime> createdAt = const Value.absent(), Value<int> rowid = const Value.absent()})
const
TranslationsCompanion.insert({required String originalTextHash, required String translatedText, Value<SolvroLocale> originalLanguageCode = const Value.absent(), required SolvroLocale translatedLanguageCode, required bool isApproved, Value<DateTime> createdAt = const Value.absent(), Value<int> rowid = const Value.absent()})

Properties

createdAt → Value<DateTime>
final
hashCode int
The hash code for this object.
no setterinherited
isApproved → Value<bool>
final
originalLanguageCode → Value<SolvroLocale>
final
originalTextHash → Value<String>
final
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translatedLanguageCode → Value<SolvroLocale>
final
translatedText → Value<String>
final

Methods

copyWith({Value<String>? originalTextHash, Value<String>? translatedText, Value<SolvroLocale>? originalLanguageCode, Value<SolvroLocale>? translatedLanguageCode, Value<bool>? isApproved, Value<DateTime>? createdAt, Value<int>? rowid}) TranslationsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? originalTextHash, Expression<String>? translatedText, Expression<int>? originalLanguageCode, Expression<int>? translatedLanguageCode, Expression<bool>? isApproved, Expression<DateTime>? createdAt, Expression<int>? rowid}) → Insertable<Translation>