BatchTranslationResult class abstract

A single translation result within a batch response.

Available extensions
Annotations
  • @freezed

Constructors

BatchTranslationResult({required String originalText, required BatchTranslationItem? translation, required bool success, String? error})
Creates a new BatchTranslationResult.
const
factory
BatchTranslationResult.fromJson(Map<String, dynamic> json)
Creates a new BatchTranslationResult from a JSON object.
factory

Properties

copyWith → $BatchTranslationResultCopyWith<BatchTranslationResult>
Create a copy of BatchTranslationResult with the given fields replaced by the non-null parameter values.
no setterinherited
error String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
originalText String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setterinherited
translation BatchTranslationItem?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BatchTranslationResult value)) → TResult

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BatchTranslationResult value)?) → TResult?

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BatchTranslationResult value)?, {required TResult orElse()}) → TResult

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String originalText, BatchTranslationItem? translation, bool success, String? error)?, {required TResult orElse()}) → TResult

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BatchTranslationResult to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String originalText, BatchTranslationItem? translation, bool success, String? error)) → TResult

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String originalText, BatchTranslationItem? translation, bool success, String? error)?) → TResult?

Available on BatchTranslationResult, provided by the BatchTranslationResultPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited