TranslationBatchResponse class abstract
A response model for batch translation services.
Contains individual translation results along with summary statistics.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TranslationBatchResponse({required List<
BatchTranslationResult> translations, required int total, required int successful, required int failed}) -
Creates a new TranslationBatchResponse.
constfactory
-
TranslationBatchResponse.fromJson(Map<
String, dynamic> json) -
Creates a new TranslationBatchResponse from a JSON object.
factory
Properties
-
copyWith
→ $TranslationBatchResponseCopyWith<
TranslationBatchResponse> -
Create a copy of TranslationBatchResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- failed → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successful → int
-
no setterinherited
- total → int
-
no setterinherited
-
translations
→ List<
BatchTranslationResult> -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TranslationBatchResponse value)) → TResult -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TranslationBatchResponse value)?) → TResult? -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TranslationBatchResponse value)?, {required TResult orElse()}) → TResult -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< BatchTranslationResult> translations, int total, int successful, int failed)?, {required TResult orElse()}) → TResult -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TranslationBatchResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< BatchTranslationResult> translations, int total, int successful, int failed)) → TResult -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< BatchTranslationResult> translations, int total, int successful, int failed)?) → TResult? -
Available on TranslationBatchResponse, provided by the TranslationBatchResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited