TranslationBatchRequest class abstract
A batch request model for translation services.
Contains multiple texts to be translated along with language codes for both the original and target languages.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TranslationBatchRequest({required List<
String> texts, required String originalLanguageCode, required String translatedLanguageCode}) -
Creates a new TranslationBatchRequest.
constfactory
-
TranslationBatchRequest.fromJson(Map<
String, dynamic> json) -
Creates a new TranslationBatchRequest from a JSON object.
factory
Properties
-
copyWith
→ $TranslationBatchRequestCopyWith<
TranslationBatchRequest> -
Create a copy of TranslationBatchRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalLanguageCode → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
texts
→ List<
String> -
no setterinherited
- translatedLanguageCode → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TranslationBatchRequest value)) → TResult -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TranslationBatchRequest value)?) → TResult? -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TranslationBatchRequest value)?, {required TResult orElse()}) → TResult -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< String> texts, String originalLanguageCode, String translatedLanguageCode)?, {required TResult orElse()}) → TResult -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TranslationBatchRequest to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< String> texts, String originalLanguageCode, String translatedLanguageCode)) → TResult -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< String> texts, String originalLanguageCode, String translatedLanguageCode)?) → TResult? -
Available on TranslationBatchRequest, provided by the TranslationBatchRequestPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited