BatchTranslationItem class abstract
A single translation item returned in a batch response.
- Available extensions
- Annotations
-
- @freezed
Constructors
- BatchTranslationItem({required String hash, required String originalText, required String translatedText, required String originalLanguageCode, required String translatedLanguageCode, required bool isApproved, required DateTime createdAt, required DateTime updatedAt})
-
Creates a new BatchTranslationItem.
constfactory
-
BatchTranslationItem.fromJson(Map<
String, dynamic> json) -
Creates a new BatchTranslationItem from a JSON object.
factory
Properties
-
copyWith
→ $BatchTranslationItemCopyWith<
BatchTranslationItem> -
Create a copy of BatchTranslationItem
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- hash → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isApproved → bool
-
no setterinherited
- originalLanguageCode → String
-
no setterinherited
- originalText → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- translatedLanguageCode → String
-
no setterinherited
- translatedText → String
-
no setterinherited
- updatedAt → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BatchTranslationItem value)) → TResult -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BatchTranslationItem value)?) → TResult? -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BatchTranslationItem value)?, {required TResult orElse()}) → TResult -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String hash, String originalText, String translatedText, String originalLanguageCode, String translatedLanguageCode, bool isApproved, DateTime createdAt, DateTime updatedAt)?, {required TResult orElse()}) → TResult -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BatchTranslationItem to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String hash, String originalText, String translatedText, String originalLanguageCode, String translatedLanguageCode, bool isApproved, DateTime createdAt, DateTime updatedAt)) → TResult -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String hash, String originalText, String translatedText, String originalLanguageCode, String translatedLanguageCode, bool isApproved, DateTime createdAt, DateTime updatedAt)?) → TResult? -
Available on BatchTranslationItem, provided by the BatchTranslationItemPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited